Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS DeepComposer.

Actions, resources, and condition keys for AWS DeepComposer - Service Authorization Reference

# Actions, resources, and condition keys for AWS DeepComposer

AWS DeepComposer (service prefix: `deepcomposer` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS DeepComposer
- Resource types defined by AWS DeepComposer
- Condition keys for AWS DeepComposer

## Actions defined by AWS DeepComposer

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateCoupon [permission only] | Grants permission to associate a DeepComposer coupon (or DSN) with the account associated with the sender of the request | Write |  |  |
CreateAudio [permission only] | Grants permission to create an audio file by converting the midi composition into a wav or mp3 file | Write | audio* |  |
CreateComposition [permission only] | Grants permission to create a multi-track midi composition | Write | composition* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateModel [permission only] | Grants permission to start creating/training a generative-model that is able to perform inference against the user-provided piano-melody to create a multi-track midi composition | Write | model* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteComposition [permission only] | Grants permission to delete the composition | Write | composition* |  |
DeleteModel | Grants permission to delete the model | Write | model* |  |
GetComposition [permission only] | Grants permission to get information about the composition | Read | composition* |  |
| aws:ResourceTag/${TagKey} |
GetModel [permission only] | Grants permission to get information about the model | Read | model* |  |
| aws:ResourceTag/${TagKey} |
GetSampleModel [permission only] | Grants permission to get information about the sample/pre-trained DeepComposer model | Read | model* |  |
ListCompositions [permission only] | Grants permission to list all the compositions owned by the sender of the request | List | composition* |  |
ListModels [permission only] | Grants permission to list all the models owned by the sender of the request | List | model* |  |
ListSampleModels [permission only] | Grants permission to list all the sample/pre-trained models provided by the DeepComposer service | List | model* |  |
ListTagsForResource | Grants permission to list tags for a resource | List | composition |  |
model |  |
| aws:ResourceTag/${TagKey} |
ListTrainingTopics [permission only] | Grants permission to list all the training options or topic for creating/training a model | List | model* |  |
TagResource | Grants permission to tag a resource | Tagging | composition |  |
model |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UntagResource | Grants permission to untag a resource | Tagging | composition |  |
model |  |
| aws:TagKeys aws:RequestTag/${TagKey} aws:ResourceTag/${TagKey} |
UpdateComposition [permission only] | Grants permission to modify the mutable properties associated with a composition | Write | composition* |  |
UpdateModel [permission only] | Grants permission to to modify the mutable properties associated with a model | Write | model* |  |

## Resource types defined by AWS DeepComposer

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
model | `arn:$ { Partition}:deepcomposer:$ { Region}:$ { Account}:model/$ { ModelId}` | aws:ResourceTag/${TagKey}
composition | `arn:$ { Partition}:deepcomposer:$ { Region}:$ { Account}:composition/$ { CompositionId}` | aws:ResourceTag/${TagKey}
audio | `arn:$ { Partition}:deepcomposer:$ { Region}:$ { Account}:audio/$ { AudioId}` |

## Condition keys for AWS DeepComposer

AWS DeepComposer defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by actions based on the presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.